# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

BIASFIELD_METADATA = Metadata(
    id="5981ee8ca338526bd3e95eb71c3b7956f4c7d239.boutiques",
    name="biasfield",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


BiasfieldParameters = typing.TypedDict('BiasfieldParameters', {
    "__STYXTYPE__": typing.Literal["biasfield"],
    "subject": str,
    "tmpdir": typing.NotRequired[str | None],
    "no_cleanup": bool,
    "help": bool,
    "debug": bool,
    "version": bool,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "biasfield": biasfield_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "biasfield": biasfield_outputs,
    }.get(t)


class BiasfieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `biasfield(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    biasfield_output: OutputPathType
    """Generated bias field in the subject MRI directory"""
    rawavg_cor_norm: OutputPathType
    """The rawavg.mgz in 256^3, 1mm^3 space with the bias field removed"""


def biasfield_params(
    subject: str,
    tmpdir: str | None = None,
    no_cleanup: bool = False,
    help_: bool = False,
    debug: bool = False,
    version: bool = False,
) -> BiasfieldParameters:
    """
    Build parameters.
    
    Args:
        subject: Subject identifier.
        tmpdir: Temporary directory.
        no_cleanup: Prevent cleanup of temporary files.
        help_: Display help information.
        debug: Enable debugging mode.
        version: Display script version info.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "biasfield",
        "subject": subject,
        "no_cleanup": no_cleanup,
        "help": help_,
        "debug": debug,
        "version": version,
    }
    if tmpdir is not None:
        params["tmpdir"] = tmpdir
    return params


def biasfield_cargs(
    params: BiasfieldParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("biasfield")
    cargs.extend([
        "--s",
        params.get("subject")
    ])
    if params.get("tmpdir") is not None:
        cargs.extend([
            "--tmp",
            params.get("tmpdir")
        ])
    if params.get("no_cleanup"):
        cargs.append("--nocleanup")
    if params.get("help"):
        cargs.append("--help")
    if params.get("debug"):
        cargs.append("--debug")
    if params.get("version"):
        cargs.append("--version")
    return cargs


def biasfield_outputs(
    params: BiasfieldParameters,
    execution: Execution,
) -> BiasfieldOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = BiasfieldOutputs(
        root=execution.output_file("."),
        biasfield_output=execution.output_file("biasfield.mgz"),
        rawavg_cor_norm=execution.output_file("rawavg.cor.norm.mgz"),
    )
    return ret


def biasfield_execute(
    params: BiasfieldParameters,
    execution: Execution,
) -> BiasfieldOutputs:
    """
    Computes the bias field by dividing the (unconformed) orig.mgz by the norm.mgz.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `BiasfieldOutputs`).
    """
    params = execution.params(params)
    cargs = biasfield_cargs(params, execution)
    ret = biasfield_outputs(params, execution)
    execution.run(cargs)
    return ret


def biasfield(
    subject: str,
    tmpdir: str | None = None,
    no_cleanup: bool = False,
    help_: bool = False,
    debug: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> BiasfieldOutputs:
    """
    Computes the bias field by dividing the (unconformed) orig.mgz by the norm.mgz.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        tmpdir: Temporary directory.
        no_cleanup: Prevent cleanup of temporary files.
        help_: Display help information.
        debug: Enable debugging mode.
        version: Display script version info.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BiasfieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BIASFIELD_METADATA)
    params = biasfield_params(
        subject=subject,
        tmpdir=tmpdir,
        no_cleanup=no_cleanup,
        help_=help_,
        debug=debug,
        version=version,
    )
    return biasfield_execute(params, execution)


__all__ = [
    "BIASFIELD_METADATA",
    "BiasfieldOutputs",
    "BiasfieldParameters",
    "biasfield",
    "biasfield_params",
]
