# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

DICOM_RENAME_METADATA = Metadata(
    id="3fa82f4f7cfa0f517393cf4bbd8d9673564b758d.boutiques",
    name="dicom-rename",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


DicomRenameParameters = typing.TypedDict('DicomRenameParameters', {
    "__STYXTYPE__": typing.Literal["dicom-rename"],
    "input_files": list[InputPathType],
    "output_base": str,
    "version": bool,
    "help": bool,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "dicom-rename": dicom_rename_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "dicom-rename": dicom_rename_outputs,
    }.get(t)


class DicomRenameOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dicom_rename(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    renamed_dicom: OutputPathType
    """Renamed output DICOM file with series and image numbers."""


def dicom_rename_params(
    input_files: list[InputPathType],
    output_base: str,
    version: bool = False,
    help_: bool = False,
) -> DicomRenameParameters:
    """
    Build parameters.
    
    Args:
        input_files: Input DICOM files to be renamed.
        output_base: Base name for output files that includes series and image\
            numbers.
        version: Print version and exit.
        help_: Print help and exit.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "dicom-rename",
        "input_files": input_files,
        "output_base": output_base,
        "version": version,
        "help": help_,
    }
    return params


def dicom_rename_cargs(
    params: DicomRenameParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("dicom-rename")
    cargs.extend([
        "-rename",
        *[execution.input_file(f) for f in params.get("input_files")]
    ])
    cargs.extend([
        "--o",
        params.get("output_base")
    ])
    if params.get("version"):
        cargs.append("--version")
    if params.get("help"):
        cargs.append("--help")
    return cargs


def dicom_rename_outputs(
    params: DicomRenameParameters,
    execution: Execution,
) -> DicomRenameOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = DicomRenameOutputs(
        root=execution.output_file("."),
        renamed_dicom=execution.output_file(params.get("output_base") + "-SSS-IIIII.dcm"),
    )
    return ret


def dicom_rename_execute(
    params: DicomRenameParameters,
    execution: Execution,
) -> DicomRenameOutputs:
    """
    Copies dicom file(s) to new path with more meaningful names.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `DicomRenameOutputs`).
    """
    params = execution.params(params)
    cargs = dicom_rename_cargs(params, execution)
    ret = dicom_rename_outputs(params, execution)
    execution.run(cargs)
    return ret


def dicom_rename(
    input_files: list[InputPathType],
    output_base: str,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> DicomRenameOutputs:
    """
    Copies dicom file(s) to new path with more meaningful names.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_files: Input DICOM files to be renamed.
        output_base: Base name for output files that includes series and image\
            numbers.
        version: Print version and exit.
        help_: Print help and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DicomRenameOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DICOM_RENAME_METADATA)
    params = dicom_rename_params(
        input_files=input_files,
        output_base=output_base,
        version=version,
        help_=help_,
    )
    return dicom_rename_execute(params, execution)


__all__ = [
    "DICOM_RENAME_METADATA",
    "DicomRenameOutputs",
    "DicomRenameParameters",
    "dicom_rename",
    "dicom_rename_params",
]
