# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

MAKE_SYMMETRIC_METADATA = Metadata(
    id="1c653a3729e019c1a68b0edb9c44bee8ba0b0c6c.boutiques",
    name="make_symmetric",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


MakeSymmetricParameters = typing.TypedDict('MakeSymmetricParameters', {
    "__STYXTYPE__": typing.Literal["make_symmetric"],
    "hemi": str,
    "input_file": InputPathType,
    "output_file": str,
    "transform_map": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "make_symmetric": make_symmetric_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "make_symmetric": make_symmetric_outputs,
    }.get(t)


class MakeSymmetricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_symmetric(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    processed_output: OutputPathType
    """Output image file after processing."""
    map_output: OutputPathType
    """Transformation map file mapping the input to the upright space."""


def make_symmetric_params(
    hemi: str,
    input_file: InputPathType,
    output_file: str,
    transform_map: str,
) -> MakeSymmetricParameters:
    """
    Build parameters.
    
    Args:
        hemi: The hemisphere to mirror; accepted values are 'lh' for left\
            hemisphere or 'rh' for right hemisphere.
        input_file: Input image in .mgz format.
        output_file: Output image in .mgz format resulting from the symmetric\
            processing.
        transform_map: Transformation map in .lta format mapping the input to\
            the upright space.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "make_symmetric",
        "hemi": hemi,
        "input_file": input_file,
        "output_file": output_file,
        "transform_map": transform_map,
    }
    return params


def make_symmetric_cargs(
    params: MakeSymmetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("make_symmetric")
    cargs.append(params.get("hemi"))
    cargs.append(execution.input_file(params.get("input_file")))
    cargs.append(params.get("output_file"))
    cargs.append(params.get("transform_map"))
    return cargs


def make_symmetric_outputs(
    params: MakeSymmetricParameters,
    execution: Execution,
) -> MakeSymmetricOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MakeSymmetricOutputs(
        root=execution.output_file("."),
        processed_output=execution.output_file(params.get("output_file")),
        map_output=execution.output_file(params.get("transform_map")),
    )
    return ret


def make_symmetric_execute(
    params: MakeSymmetricParameters,
    execution: Execution,
) -> MakeSymmetricOutputs:
    """
    Registers an input image to its left/right reversed version using
    mri_robust_register in a half-way space and mirrors the selected hemisphere.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `MakeSymmetricOutputs`).
    """
    params = execution.params(params)
    cargs = make_symmetric_cargs(params, execution)
    ret = make_symmetric_outputs(params, execution)
    execution.run(cargs)
    return ret


def make_symmetric(
    hemi: str,
    input_file: InputPathType,
    output_file: str,
    transform_map: str,
    runner: Runner | None = None,
) -> MakeSymmetricOutputs:
    """
    Registers an input image to its left/right reversed version using
    mri_robust_register in a half-way space and mirrors the selected hemisphere.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemi: The hemisphere to mirror; accepted values are 'lh' for left\
            hemisphere or 'rh' for right hemisphere.
        input_file: Input image in .mgz format.
        output_file: Output image in .mgz format resulting from the symmetric\
            processing.
        transform_map: Transformation map in .lta format mapping the input to\
            the upright space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeSymmetricOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_SYMMETRIC_METADATA)
    params = make_symmetric_params(
        hemi=hemi,
        input_file=input_file,
        output_file=output_file,
        transform_map=transform_map,
    )
    return make_symmetric_execute(params, execution)


__all__ = [
    "MAKE_SYMMETRIC_METADATA",
    "MakeSymmetricOutputs",
    "MakeSymmetricParameters",
    "make_symmetric",
    "make_symmetric_params",
]
