# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

MRI_MARK_TEMPORAL_LOBE_METADATA = Metadata(
    id="75e6e60a85ce6a2bfb0234747d1412e2709192d8.boutiques",
    name="mri_mark_temporal_lobe",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


MriMarkTemporalLobeParameters = typing.TypedDict('MriMarkTemporalLobeParameters', {
    "__STYXTYPE__": typing.Literal["mri_mark_temporal_lobe"],
    "spacing": typing.NotRequired[str | None],
    "use_gradient": bool,
    "subjects": list[InputPathType],
    "output_file": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "mri_mark_temporal_lobe": mri_mark_temporal_lobe_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "mri_mark_temporal_lobe": mri_mark_temporal_lobe_outputs,
    }.get(t)


class MriMarkTemporalLobeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_mark_temporal_lobe(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Marked temporal lobe output file"""


def mri_mark_temporal_lobe_params(
    subjects: list[InputPathType],
    output_file: str,
    spacing: str | None = None,
    use_gradient: bool = False,
) -> MriMarkTemporalLobeParameters:
    """
    Build parameters.
    
    Args:
        subjects: Subject MRI images.
        output_file: Output file for marked temporal lobes.
        spacing: The spacing of classifiers in canonical space.
        use_gradient: Flag to use intensity gradient as input to classifier.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "mri_mark_temporal_lobe",
        "use_gradient": use_gradient,
        "subjects": subjects,
        "output_file": output_file,
    }
    if spacing is not None:
        params["spacing"] = spacing
    return params


def mri_mark_temporal_lobe_cargs(
    params: MriMarkTemporalLobeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("mri_mark_temporal_lobe")
    if params.get("spacing") is not None:
        cargs.extend([
            "-spacing",
            params.get("spacing")
        ])
    if params.get("use_gradient"):
        cargs.append("-gradient" + "".join([execution.input_file(f) for f in params.get("subjects")]) + params.get("output_file"))
    return cargs


def mri_mark_temporal_lobe_outputs(
    params: MriMarkTemporalLobeParameters,
    execution: Execution,
) -> MriMarkTemporalLobeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MriMarkTemporalLobeOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(params.get("output_file")),
    )
    return ret


def mri_mark_temporal_lobe_execute(
    params: MriMarkTemporalLobeParameters,
    execution: Execution,
) -> MriMarkTemporalLobeOutputs:
    """
    A tool for marking the temporal lobe in MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `MriMarkTemporalLobeOutputs`).
    """
    params = execution.params(params)
    cargs = mri_mark_temporal_lobe_cargs(params, execution)
    ret = mri_mark_temporal_lobe_outputs(params, execution)
    execution.run(cargs)
    return ret


def mri_mark_temporal_lobe(
    subjects: list[InputPathType],
    output_file: str,
    spacing: str | None = None,
    use_gradient: bool = False,
    runner: Runner | None = None,
) -> MriMarkTemporalLobeOutputs:
    """
    A tool for marking the temporal lobe in MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: Subject MRI images.
        output_file: Output file for marked temporal lobes.
        spacing: The spacing of classifiers in canonical space.
        use_gradient: Flag to use intensity gradient as input to classifier.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMarkTemporalLobeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MARK_TEMPORAL_LOBE_METADATA)
    params = mri_mark_temporal_lobe_params(
        spacing=spacing,
        use_gradient=use_gradient,
        subjects=subjects,
        output_file=output_file,
    )
    return mri_mark_temporal_lobe_execute(params, execution)


__all__ = [
    "MRI_MARK_TEMPORAL_LOBE_METADATA",
    "MriMarkTemporalLobeOutputs",
    "MriMarkTemporalLobeParameters",
    "mri_mark_temporal_lobe",
    "mri_mark_temporal_lobe_params",
]
