# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

MRIS_TOPO_FIXER_METADATA = Metadata(
    id="8f80d79d55bacb40b2cbd2f6150f071f3dec1313.boutiques",
    name="mris_topo_fixer",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


MrisTopoFixerParameters = typing.TypedDict('MrisTopoFixerParameters', {
    "__STYXTYPE__": typing.Literal["mris_topo_fixer"],
    "input_surface": InputPathType,
    "output_surface": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "mris_topo_fixer": mris_topo_fixer_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "mris_topo_fixer": mris_topo_fixer_outputs,
    }.get(t)


class MrisTopoFixerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_topo_fixer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fixed_surface: OutputPathType
    """Surface file with fixed topology."""


def mris_topo_fixer_params(
    input_surface: InputPathType,
    output_surface: str,
) -> MrisTopoFixerParameters:
    """
    Build parameters.
    
    Args:
        input_surface: Input surface file that needs topological fixing.
        output_surface: Output surface file with fixed topology.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "mris_topo_fixer",
        "input_surface": input_surface,
        "output_surface": output_surface,
    }
    return params


def mris_topo_fixer_cargs(
    params: MrisTopoFixerParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("mris_topo_fixer")
    cargs.append(execution.input_file(params.get("input_surface")))
    cargs.append(params.get("output_surface"))
    return cargs


def mris_topo_fixer_outputs(
    params: MrisTopoFixerParameters,
    execution: Execution,
) -> MrisTopoFixerOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MrisTopoFixerOutputs(
        root=execution.output_file("."),
        fixed_surface=execution.output_file(params.get("output_surface")),
    )
    return ret


def mris_topo_fixer_execute(
    params: MrisTopoFixerParameters,
    execution: Execution,
) -> MrisTopoFixerOutputs:
    """
    FreeSurfer tool for fixing topological defects in cortical surface meshes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `MrisTopoFixerOutputs`).
    """
    params = execution.params(params)
    cargs = mris_topo_fixer_cargs(params, execution)
    ret = mris_topo_fixer_outputs(params, execution)
    execution.run(cargs)
    return ret


def mris_topo_fixer(
    input_surface: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> MrisTopoFixerOutputs:
    """
    FreeSurfer tool for fixing topological defects in cortical surface meshes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file that needs topological fixing.
        output_surface: Output surface file with fixed topology.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTopoFixerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TOPO_FIXER_METADATA)
    params = mris_topo_fixer_params(
        input_surface=input_surface,
        output_surface=output_surface,
    )
    return mris_topo_fixer_execute(params, execution)


__all__ = [
    "MRIS_TOPO_FIXER_METADATA",
    "MrisTopoFixerOutputs",
    "MrisTopoFixerParameters",
    "mris_topo_fixer",
    "mris_topo_fixer_params",
]
